{ "identity": { "name": "", "UPC": "", "DSLD ID": "", "FDC ID": "" }, "brand": { "name": "" }, "measures": { "form": # detail at "form" # # For NIH supps these are necessary for # calculating the mass. # # { defined, recommendations } # "recommendations": { "serving size": { "grams": { "fraction string": "28" } }, "servings per package": "" }, "energy": { "per package": { "calories": { "decimal string: "", "fraction string": "" }, "joules": { "decimal string: "", "fraction string": "" } } }, ''' USDA: NIH: ''' "mass + mass equivalents, of measured ingredients ": { "per package": { "grams": { "decimal string: "", "fraction string": "", "grams sci note": [ "113.00", "e0" ] }, "ounces": { "decimal string: "", "fraction string": "" } } }, # # non-essential, this is not present # for most supplements. # "mass": { "per package": { "grams": { "decimal string: "", "fraction string": "" }, "ounces": { "decimal string: "", "fraction string": "" } } }, "mass equivalents": { "per package": { "grams": { "decimal string: "", "fraction string": "" }, "ounces": { "decimal string: "", "fraction string": "" } } }, "volume": { "per package": { "liters": { "decimal string: "", "fraction string": "" } } } }, "essential nutrients grove": [{ # # The ingredient from either: # # USDA: # foodNutrients (flat list) # # NIH: # ingredientRows (tree) # nestedRows # nestedRows # "ingredient": { "name": "vitamin b", }, # # The essential nutrient from the # essential nutrient grove DB. # "essential": { "names": [ "vitamin b", "cobalamin" ], "includes": [] }, "includes": [] }], "measured ingredients": { "shapes channel": [{ }], "grove": [{ "name": "vitamin b", "measures": { # # This is probably almost always one or the other, # but that would imply that it would be like, # 0 + 100 or 100 + 0, therefore, this is solid. # "mass + mass equivalents": { "per package": { "grams": { "decimal string": "", "fraction string": "" }, "ounces": { } } }, # # if IU # "energy": { "per package": { "calories": { "decimal string": "", "fraction string": "" }, "joules": { "decimal string": "", "fraction string": "" } } }, # # if IU # "biological activity": { "per package": { "IU": { "decimal string": "", "fraction string": "" } } }, ''' This is 2nd priority ''' "mass": { "per package": { "grams": { "decimal string": "", "fraction string": "" }, "ounces": { } } }, ''' This is 2nd priority ''' "mass equivalent": { "per package": { "grams": { "equivalent": "DFE", "decimal string": "", "fraction string": "" } } }, }, "includes": [] }] }, "unmeasured ingredients": { # # USDA sends a string "ingredients" # "string": "", # # NIH sends a list of "otherIngredients" # "list": [] }, "reference": [], # # unique to NIH supps # "statements": [] }